@@ -3,18 +3,17 @@ Check lexibank plumbing for lexibank datasets
 """
 import functools
 
-from cldfbench.cli_util import with_datasets, add_catalog_spec
+from cldfbench.cli_util import with_datasets
 
 from pylexibank.cli_util import add_dataset_spec, warning
 
 
 def register(parser):
     add_dataset_spec(parser, multiple=True)
-    add_catalog_spec(parser, 'glottolog')
 
 
-def check(ds, args):
-    warn = functools.partial(warning, args, dataset=ds)
+def check(ds, args, warnings=None):
+    warn = functools.partial(warning, args, dataset=ds, warnings=warnings)
 
     args.log.info('checking {0} - plumbing'.format(ds))
 
